==> iaxmodem-1.1.0.tar.gz: iaxmodem-1.1.0/lib/spandsp/src/v17tx_fixed_rrc.h <==
#define PULSESHAPER_GAIN        0.948561f
#define PULSESHAPER_COEFF_SETS  10
static const int16_t pulseshaper[PULSESHAPER_COEFF_SETS][9] =
{
    {
             -89,     /* Filter 0 */
            -561,
            2002,
           -5223,
           19071,
           19071,
           -5223,
            2002,
            -561
    },
    {
              97,     /* Filter 1 */
            -922,
            2553,
           -6054,
           23507,
           14325,
           -3959,
            1300,
            -183
    },
    {
             297,     /* Filter 2 */
           -1210,
            2855,
           -6268,
           27331,
            9577,
           -2461,
             548,
             159
    },
    {
             478,     /* Filter 3 */
           -1370,
            2827,
           -5713,
           30276,
            5120,
            -924,
            -157,
             426
    },
    {
             605,     /* Filter 4 */
           -1359,
            2421,
           -4291,
           32132,
            1207,
             482,
            -741,
             593
    },
    {
             650,     /* Filter 5 */
           -1150,
            1627,
           -1970,
           32767,
           -1970,
            1627,
           -1150,
             650
    },
    {
             593,     /* Filter 6 */
            -741,
             482,
            1207,
           32132,
           -4291,
            2421,
           -1359,
             605
    },
    {
             426,     /* Filter 7 */
            -157,
            -924,
            5120,
           30276,
           -5713,
            2827,
           -1370,
             478
    },
    {
             159,     /* Filter 8 */
             548,
           -2461,
            9577,
           27331,
           -6268,
            2855,
           -1210,
             297
    },
    {
            -183,     /* Filter 9 */
            1300,
           -3959,
           14325,
           23507,
           -6054,
            2553,
            -922,
              97
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v17tx_fixed_rrc.h <==
#define TX_PULSESHAPER_GAIN        0.948561f
#define TX_PULSESHAPER_COEFF_SETS  10
static const int16_t tx_pulseshaper[TX_PULSESHAPER_COEFF_SETS][9] =
{
    {
             -89,     /* Filter 0 */
            -561,
            2002,
           -5223,
           19071,
           19071,
           -5223,
            2002,
            -561
    },
    {
              97,     /* Filter 1 */
            -922,
            2553,
           -6054,
           23507,
           14325,
           -3959,
            1300,
            -183
    },
    {
             297,     /* Filter 2 */
           -1210,
            2855,
           -6268,
           27331,
            9577,
           -2461,
             548,
             159
    },
    {
             478,     /* Filter 3 */
           -1370,
            2827,
           -5713,
           30276,
            5120,
            -924,
            -157,
             426
    },
    {
             605,     /* Filter 4 */
           -1359,
            2421,
           -4291,
           32132,
            1207,
             482,
            -741,
             593
    },
    {
             650,     /* Filter 5 */
           -1150,
            1627,
           -1970,
           32767,
           -1970,
            1627,
           -1150,
             650
    },
    {
             593,     /* Filter 6 */
            -741,
             482,
            1207,
           32132,
           -4291,
            2421,
           -1359,
             605
    },
    {
             426,     /* Filter 7 */
            -157,
            -924,
            5120,
           30276,
           -5713,
            2827,
           -1370,
             478
    },
    {
             159,     /* Filter 8 */
             548,
           -2461,
            9577,
           27331,
           -6268,
            2855,
           -1210,
             297
    },
    {
            -183,     /* Filter 9 */
            1300,
           -3959,
           14325,
           23507,
           -6054,
            2553,
            -922,
              97
    }
};
